==> tetzle_2.2.3.orig.tar.gz: tetzle-2.2.3/translations/tetzle_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Malfermi bildon</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Apero</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcioj</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Bevelaj borderoj</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Ĵetitaj ombroj</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Koloroj</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fono:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Ombro:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Bildo mankas.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Bonvile atendu</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Ŝargado de bildo...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Generado de puzlo...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Kreado de eroj...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Ŝargado de puzlo...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Nekonata aranĝo de datumoj</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Nekonata ero &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Eraro dum analizado de XML-dosiero.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Ŝargado de eroj...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Ricevado de eroj...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Metado de eroj...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukcese</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Elektu ludon</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Aktuala ludo</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nova ludo</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Ecoj de bildo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nomo:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etkedoj:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Elektu lingvon de alikaĵo:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingvo de sistemo&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Noto</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bonvole restartigu ĉi tiun aplikaĵon por efektivigi la ŝanĝon de lingvo.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Aldoni bildon</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Forigi bildon</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Ecoj de bildo</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 eroj</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopiado de bildo...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Ĉu forigi elektitan bildon?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Ĉu forigi elektitan bildon?

Estas konservataj ludoj, uzantaj ĉi tiun bildon, kiuj estas ankaŭ forigotaj.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sentitola</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sentitola</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 eroj %2 %3% plenumita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Forigi ludon</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Ĉu forigi ludon?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Superrigardo</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Aldoni etikedon</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Forigi etikedon</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Senetikeda</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Ĉiuj bildoj</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sentitola %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Ĉu forigi elektitan etikedon?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Mi pardonpetas</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Samnoma etikedo jam ekzistas.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzlo</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Ludo</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Ricevi erojn</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Stir+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Eliri</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Elektu...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vido</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Pl&amp;igrandigi</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Malpligrandigi</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Plejbona adapto</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>&amp;Montri superrigardon</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Langeto</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>T&amp;utekrane</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Stir+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Apero...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Lingvo...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Stiriloj</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Pri</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Pri &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Stiriloj</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Prenu erojn;&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Maldekstra alklako aŭ spaceto</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Demetu erojn:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Elektu erojn:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Maldekstra ŝovo</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Turnu erojn:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Dekstra alklako, stirklavo + maldekstra alklako aŭ R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ŝovu puzlon:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Meza alklako, majuskliga klavo + dekstra alklako aŭ sagoj</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pligrandigu puzlon:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Rulumrado aŭ +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Movu kursoron:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Movi muson aŭ W, A, D kaj S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Pri Tetzlo</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Puzlo kun 4-kvadratoj por eroj</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Kopirajto &amp;copy; 2008-%1 Graeme GOTT</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publikigita sub la permesilo &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Elektu OpenGL-an version.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versio</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> tetzle_3.0.0.orig.tar.gz: tetzle-3.0.0/translations/tetzle_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Malfermi bildon</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Apero</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcioj</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Bevelaj borderoj</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Ĵetitaj ombroj</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Koloroj</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fono:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Ombro:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Bildo mankas.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Bonvile atendu</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Ŝargado de bildo...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Generado de puzlo...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Kreado de eroj...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Ŝargado de puzlo...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Nekonata aranĝo de datumoj</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Nekonata ero &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Eraro dum analizado de XML-dosiero.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Ŝargado de eroj...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Ricevado de eroj...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Metado de eroj...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukcese</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Elektu ludon</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Aktuala ludo</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nova ludo</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Ecoj de bildo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nomo:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etkedoj:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Elektu lingvon de alikaĵo:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingvo de sistemo&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Noto</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bonvole restartigu ĉi tiun aplikaĵon por efektivigi la ŝanĝon de lingvo.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Aldoni bildon</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Forigi bildon</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Ecoj de bildo</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 eroj</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopiado de bildo...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sentitola</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sentitola</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 eroj %2 %3% plenumita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Forigi ludon</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Ĉu forigi ludon?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Superrigardo</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Aldoni etikedon</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Forigi etikedon</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Senetikeda</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Ĉiuj bildoj</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sentitola %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Ĉu forigi elektitan etikedon?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Mi pardonpetas</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Samnoma etikedo jam ekzistas.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzlo</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Ludo</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Ricevi erojn</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Stir+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Eliri</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Elektu...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vido</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Pl&amp;igrandigi</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Malpligrandigi</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Plejbona adapto</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>&amp;Montri superrigardon</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Langeto</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>T&amp;utekrane</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Stir+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Apero...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Lingvo...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Stiriloj</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Pri</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Pri &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Stiriloj</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Prenu erojn;&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Maldekstra alklako aŭ spaceto</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Demetu erojn:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Elektu erojn:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Maldekstra ŝovo</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Turnu erojn:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Dekstra alklako, stirklavo + maldekstra alklako aŭ R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ŝovu puzlon:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Meza alklako, majuskliga klavo + dekstra alklako aŭ sagoj</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pligrandigu puzlon:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Rulumrado aŭ +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Movu kursoron:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Movi muson aŭ W, A, D kaj S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Pri Tetzlo</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Puzlo kun 4-kvadratoj por eroj</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Kopirajto &amp;copy; 2008-%1 Graeme GOTT</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publikigita sub la permesilo &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
